.. _qt_plotting:

Pyvista and PyQt
----------------

Using `pyqt` you can embed the `Plotter` class within a `pyqt` widget to add `pyvista` to a `Qt` application within Python.  You can also have a plot in a separate thread from the main python thread using a background plotter class.  For more details, see `pyvistaqt <https://qtdocs.pyvista.org>`_!
